@@ -10,6 +10,7 @@ use tg_bindings::{
     request_privileges, BlockParams, ConsensusParams, EvidenceParams, GovProposal, Privilege,
     PrivilegeChangeMsg, TgradeMsg, TgradeSudoMsg,
 };
+use tg_utils::ensure_from_older_version;
 
 use crate::msg::{ExecuteMsg, InstantiateMsg, QueryMsg, ValidatorProposal};
 use crate::ContractError;
@@ -242,6 +243,12 @@ fn privilege_change(_deps: DepsMut, change: PrivilegeChangeMsg) -> Response {
     }
 }
 
+#[cfg_attr(not(feature = "library"), entry_point)]
+pub fn migrate(deps: DepsMut, _env: Env, _msg: Empty) -> Result<Response, ContractError> {
+    ensure_from_older_version(deps.storage, CONTRACT_NAME, CONTRACT_VERSION)?;
+    Ok(Response::new())
+}
+
 #[cfg(test)]
 mod tests {
     use cosmwasm_std::{
